@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2012 Vaclav Slavik
+ *  Copyright (C) 1999-2013 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -734,15 +734,15 @@ bool CatalogParser::Parse()
         }
 
         // deleted lines:
-        else if (ReadParam(line, _T("#~ "), dummy))
+        else if (ReadParam(line, _T("#~"), dummy))
         {
             wxArrayString deletedLines;
             deletedLines.Add(line);
             mlinenum = m_textFile->GetCurrentLine() + 1;
             while (!(line = ReadTextLine(m_textFile)).empty())
             {
-                // if line does not start with "#~ " anymore, stop reading
-                if (!ReadParam(line, _T("#~ "), dummy))
+                // if line does not start with "#~" anymore, stop reading
+                if (!ReadParam(line, _T("#~"), dummy))
                     break;
                 // if the line starts with "#~ msgid", we skipped an empty line
                 // and it's a new entry, so stop reading too (see bug #329)
@@ -1147,41 +1147,35 @@ int Catalog::SetBookmark(int id, Bookmark bookmark)
 namespace
 {
 
-bool CanEncodeStringToCharset(const wxString& s, wxMBConv& conv)
+inline bool CanEncodeStringToCharset(const wxString& s, wxMBConv& conv)
 {
     if (s.empty())
         return true;
-    if (!s.mb_str(conv))
+    const wxCharBuffer converted(s.mb_str(conv));
+#if wxCHECK_VERSION(2,9,0)
+    if ( converted.length() == 0 )
+#else
+    const char *cs = (const char*)converted;
+    if ( cs == NULL || strlen(cs) == 0 )
+#endif
         return false;
     return true;
 }
 
-bool CanEncodeToCharset(Catalog& catalog, const wxString& charset)
+bool CanEncodeToCharset(const wxTextFile& f, const wxString& charset)
 {
     if (charset.Lower() == _T("utf-8") || charset.Lower() == _T("utf8"))
         return true;
 
     wxCSConv conv(charset);
 
-    catalog.Header().UpdateDict();
-    const Catalog::HeaderData::Entries& hdr(catalog.Header().GetAllHeaders());
-
-    for (Catalog::HeaderData::Entries::const_iterator i = hdr.begin();
-            i != hdr.end(); i++)
+    const size_t lines = f.GetLineCount();
+    for ( size_t i = 0; i < lines; i++ )
     {
-        if (!CanEncodeStringToCharset(i->Value, conv))
+        if ( !CanEncodeStringToCharset(f.GetLine(i), conv) )
             return false;
     }
 
-    size_t cnt = catalog.GetCount();
-    for (size_t i = 0; i < cnt; i++)
-    {
-        if (!CanEncodeStringToCharset(catalog[i].GetTranslation(), conv) ||
-            !CanEncodeStringToCharset(catalog[i].GetString(), conv))
-        {
-            return false;
-        }
-    }
     return true;
 }
 
@@ -1375,28 +1369,21 @@ bool Catalog::Save(const wxString& po_file, bool save_mo, int& validation_errors
 
 bool Catalog::DoSaveOnly(const wxString& po_file)
 {
-    /* Detect CRLF format: */
     wxTextFileType crlf = GetDesiredCRLFFormat(po_file);
 
-    /* Save .po file: */
-    wxString charset(m_header.Charset);
-    if (!charset || charset == _T("CHARSET"))
-        charset = _T("UTF-8");
-
-    if (!CanEncodeToCharset(*this, charset))
-    {
-        wxString msg;
-        msg.Printf(_("The catalog couldn't be saved in '%s' charset as\nspecified in catalog settings. It was saved in UTF-8 instead\nand the setting was modified accordingly."), charset.c_str());
-        wxMessageBox(msg, _("Error saving catalog"),
-                     wxOK | wxICON_EXCLAMATION);
-        charset = _T("UTF-8");
-    }
-    m_header.Charset = charset;
-
     wxTextFile f;
     if (!f.Create(po_file))
         return false;
 
+    return DoSaveOnly(f, crlf);
+}
+
+bool Catalog::DoSaveOnly(wxTextFile& f, wxTextFileType crlf)
+{
+    /* Save .po file: */
+    if (!m_header.Charset || m_header.Charset == _T("CHARSET"))
+        m_header.Charset = _T("UTF-8");
+
     SaveMultiLines(f, m_header.Comment);
     f.AddLine(_T("msgid \"\""));
     f.AddLine(_T("msgstr \"\""));
@@ -1435,7 +1422,7 @@ bool Catalog::DoSaveOnly(const wxString& po_file)
             dummy = FormatStringForFile(data.GetPluralString());
             SaveMultiLines(f, _T("msgid_plural \"") + dummy + _T("\""));
 
-            for (size_t i = 0; i < data.GetNumberOfTranslations(); i++)
+            for (unsigned i = 0; i < data.GetNumberOfTranslations(); i++)
             {
                 dummy = FormatStringForFile(data.GetTranslation(i));
                 wxString hdr = wxString::Format(_T("msgstr[%u] \""), i);
@@ -1471,7 +1458,22 @@ bool Catalog::DoSaveOnly(const wxString& po_file)
             f.AddLine(deletedItem.GetDeletedLines()[j]);
     }
 
-    return f.Write(crlf, wxCSConv(charset));
+    if (!CanEncodeToCharset(f, m_header.Charset))
+    {
+        wxString msg;
+        msg.Printf(_("The catalog couldn't be saved in '%s' charset as\nspecified in catalog settings. It was saved in UTF-8 instead\nand the setting was modified accordingly."),
+                   m_header.Charset.c_str());
+        wxMessageBox(msg, _("Error saving catalog"),
+                     wxOK | wxICON_EXCLAMATION);
+        m_header.Charset = _T("UTF-8");
+
+        // Re-do the save again because we modified a header:
+        f.Clear();
+        return DoSaveOnly(f, crlf);
+    }
+
+    // Otherwise everything can be safely saved:
+    return f.Write(crlf, wxCSConv(m_header.Charset));
 }
 
 
@@ -1663,6 +1665,17 @@ bool Catalog::Merge(Catalog *refcat)
 }
 
 
+static inline wxString ItemMergeSummary(const CatalogItem& item)
+{
+    wxString s = item.GetString();
+    if ( item.HasPlural() )
+        s += _T("|") + item.GetPluralString();
+    if ( item.HasContext() )
+        s += wxString::Format(_T("%s [%s]"), s.c_str(), item.GetContext().c_str());
+
+    return s;
+}
+
 void Catalog::GetMergeSummary(Catalog *refcat,
                               wxArrayString& snew, wxArrayString& sobsolete)
 {
@@ -1672,22 +1685,22 @@ void Catalog::GetMergeSummary(Catalog *refcat,
     std::set<wxString> strsThis, strsRef;
 
     for ( unsigned i = 0; i < GetCount(); i++ )
-        strsThis.insert((*this)[i].GetString());
+        strsThis.insert(ItemMergeSummary((*this)[i]));
     for ( unsigned i = 0; i < refcat->GetCount(); i++ )
-        strsRef.insert((*refcat)[i].GetString());
+        strsRef.insert(ItemMergeSummary((*refcat)[i]));
 
     unsigned i;
 
-    for (i = 0; i < GetCount(); i++)
+    for ( std::set<wxString>::const_iterator i = strsThis.begin(); i != strsThis.end(); ++i )
     {
-        if (strsRef.find((*this)[i].GetString()) == strsRef.end())
-            sobsolete.Add((*this)[i].GetString());
+        if (strsRef.find(*i) == strsRef.end())
+            sobsolete.Add(*i);
     }
 
-    for (i = 0; i < refcat->GetCount(); i++)
+    for ( std::set<wxString>::const_iterator i = strsRef.begin(); i != strsRef.end(); ++i )
     {
-        if (strsThis.find((*refcat)[i].GetString()) == strsThis.end())
-            snew.Add((*refcat)[i].GetString());
+        if (strsThis.find(*i) == strsThis.end())
+            snew.Add(*i);
     }
 }
 
