@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2012 Vaclav Slavik
+ *  Copyright (C) 1999-2013 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -328,7 +328,7 @@ void PoeditApp::SetDefaultParsers(wxConfigBase *cfg)
         Parser p;
         p.Name = s_gettextLangs[i].name;
         p.Extensions = s_gettextLangs[i].exts;
-        p.Command = wxString(_T("xgettext")) + langflag + _T(" --force-po -o %o %C %K %F");
+        p.Command = wxString(_T("xgettext")) + langflag + _T(" --add-comments=TRANSLATORS --force-po -o %o %C %K %F");
         p.KeywordItem = _T("-k%k");
         p.FileItem = _T("%f");
         p.CharsetItem = _T("--from-code=%c");
@@ -366,6 +366,18 @@ void PoeditApp::SetDefaultParsers(wxConfigBase *cfg)
         }
     }
 
+    // Poedit 1.5.6 had a breakage, it add --add-comments without space in front of it.
+    // Repair this automatically:
+    for (size_t i = 0; i < pdb.GetCount(); i++)
+    {
+        wxString& cmd = pdb[i].Command;
+        if (cmd.Contains(_T("--add-comments=")) && !cmd.Contains(_T(" --add-comments=")))
+        {
+            cmd.Replace(_T("--add-comments="), _T(" --add-comments="));
+            changed = true;
+        }
+    }
+
     if (changed)
     {
         pdb.Write(cfg);
@@ -532,7 +544,7 @@ void PoeditApp::OnAbout(wxCommandEvent&)
 #ifndef __WXMAC__
     about.SetDescription(_("Poedit is an easy to use translations editor."));
 #endif
-    about.SetCopyright(_T("Copyright \u00a9 1999-2012 Vaclav Slavik"));
+    about.SetCopyright(_T("Copyright \u00a9 1999-2013 Vaclav Slavik"));
 #ifdef __WXGTK__ // other ports would show non-native about dlg
     about.SetWebSite(_T("http://www.poedit.net"));
 #endif
@@ -619,11 +631,11 @@ void PoeditApp::AskForDonations(wxWindow *parent)
     sizer->Add(big);
 
     wxStaticText *desc = new wxStaticText(&dlg, wxID_ANY,
-            _T("A lot of time and effort have gone into development\n")
-            _T("of Poedit. If it's useful to you, please consider showing\n")
+            _T("A lot of time and effort has gone into the development\n")
+            _T("of Poedit. If you find it useful, please consider showing\n")
             _T("your appreciation with a donation.\n")
             _T("\n")
-            _T("Donate or not, there will be no difference in Poedit's\n")
+            _T("Donation or not, there will be no difference in Poedit's\n")
             _T("features and functionality.")
             );
 #ifdef __WXMAC__
