@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2012 Vaclav Slavik
+ *  Copyright (C) 1999-2013 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -51,7 +51,7 @@ public:
     ~FileViewer();
 
     /// Shows given reference, i.e. loads the file
-    void ShowReference(const wxString& ref);
+    void ShowReference(wxString ref);
 
     bool FileOk() { return !m_current.empty(); }
 
